@@ -250,10 +250,10 @@ public:
     virtual ~KGameCanvasDummy();
 
     /** This function does nothing (of course) */
-    void paint(QPainter* p) Q_DECL_OVERRIDE;
+    void paint(QPainter* p) override;
 
     /** This returns an empty rectangle */
-    QRect rect() const Q_DECL_OVERRIDE;
+    QRect rect() const override;
 };
 
 
@@ -273,14 +273,14 @@ private:
     mutable QRect m_last_child_rect;
 
     void paintInternal(QPainter* p, const QRect& prect, const QRegion& preg,
-                                          const QPoint& delta, double cumulative_opacity) Q_DECL_OVERRIDE;
+                                          const QPoint& delta, double cumulative_opacity) override;
 
-    void ensureAnimating() Q_DECL_OVERRIDE;
-    void ensurePendingUpdate() Q_DECL_OVERRIDE;
-    void invalidate(const QRect& r, bool translate = true) Q_DECL_OVERRIDE;
-    void invalidate(const QRegion& r, bool translate = true) Q_DECL_OVERRIDE;
-    void updateChanges() Q_DECL_OVERRIDE;
-    void changed() Q_DECL_OVERRIDE;
+    void ensureAnimating() override;
+    void ensurePendingUpdate() override;
+    void invalidate(const QRect& r, bool translate = true) override;
+    void invalidate(const QRegion& r, bool translate = true) override;
+    void updateChanges() override;
+    void changed() override;
 
 public:
     /** Constructor */
@@ -289,18 +289,18 @@ public:
     virtual ~KGameCanvasGroup();
 
     /** This paints all the children */
-    void paint(QPainter* p) Q_DECL_OVERRIDE;
+    void paint(QPainter* p) override;
 
     /** This returns the bouding rect of all children */
-    QRect rect() const Q_DECL_OVERRIDE;
+    QRect rect() const override;
 
     /** Animations step, updates the animation for the children */
-    void advance(int msecs) Q_DECL_OVERRIDE;
+    void advance(int msecs) override;
 
     /** returns the toplevel canvas (or null if it is in an orphan tree) */
-    KGameCanvasWidget* topLevelCanvas() Q_DECL_OVERRIDE;
+    KGameCanvasWidget* topLevelCanvas() override;
 
-    QPoint canvasPosition() const Q_DECL_OVERRIDE;
+    QPoint canvasPosition() const override;
 };
 
 /**
@@ -331,8 +331,8 @@ public:
     /** Sets the picture of the sprite */
     void setPicture(const QPicture& picture);
 
-    void paint(QPainter* p) Q_DECL_OVERRIDE;
-    QRect rect() const Q_DECL_OVERRIDE;
+    void paint(QPainter* p) override;
+    QRect rect() const override;
 };
 
 /**
@@ -363,9 +363,9 @@ public:
     /** Sets the pixmap of the sprite */
     void setPixmap(const QPixmap& pixmap);
 
-    void paint(QPainter* p) Q_DECL_OVERRIDE;
-    QRect rect() const Q_DECL_OVERRIDE;
-    bool layered() const Q_DECL_OVERRIDE { return false; }
+    void paint(QPainter* p) override;
+    QRect rect() const override;
+    bool layered() const override { return false; }
 };
 
 /**
@@ -383,7 +383,7 @@ class KDEGAMESPRIVATE_EXPORT KGameCanvasRenderedPixmap : public KGameCanvasPixma
 public:
 	KGameCanvasRenderedPixmap(KGameRenderer* renderer, const QString& spriteKey, KGameCanvasAbstract* canvas = 0);
 protected:
-	void receivePixmap(const QPixmap& pixmap) Q_DECL_OVERRIDE;
+	void receivePixmap(const QPixmap& pixmap) override;
 };
 
 /**
@@ -433,9 +433,9 @@ public:
     /** Sets if the origin of the brush will be moved with the pixmap */
     void setMoveOrigin(bool move_orig);
 
-    void paint(QPainter* p) Q_DECL_OVERRIDE;
-    QRect rect() const Q_DECL_OVERRIDE;
-    bool layered() const Q_DECL_OVERRIDE { return false; }
+    void paint(QPainter* p) override;
+    QRect rect() const override;
+    bool layered() const override { return false; }
 };
 
 
@@ -471,9 +471,9 @@ public:
     /** Sets the size */
     void setSize(const QSize &size);
 
-    void paint(QPainter* p) Q_DECL_OVERRIDE;
-    QRect rect() const Q_DECL_OVERRIDE;
-    bool layered() const Q_DECL_OVERRIDE { return false; }
+    void paint(QPainter* p) override;
+    QRect rect() const override;
+    bool layered() const override { return false; }
 };
 
 /**
@@ -556,9 +556,9 @@ public:
     /** Sets the positioning style */
     void setPositioning(HPos hp, VPos vp);
 
-    void paint(QPainter* p) Q_DECL_OVERRIDE;
-    QRect rect() const Q_DECL_OVERRIDE;
-    bool layered() const Q_DECL_OVERRIDE { return false; }
+    void paint(QPainter* p) override;
+    QRect rect() const override;
+    bool layered() const override { return false; }
 };
 
 /**
@@ -579,12 +579,12 @@ private:
 
     class  KGameCanvasWidgetPrivate *priv;
 
-    void ensureAnimating() Q_DECL_OVERRIDE;
-    void ensurePendingUpdate() Q_DECL_OVERRIDE;
-    void invalidate(const QRect& r, bool translate = true) Q_DECL_OVERRIDE;
-    void invalidate(const QRegion& r, bool translate = true) Q_DECL_OVERRIDE;
+    void ensureAnimating() override;
+    void ensurePendingUpdate() override;
+    void invalidate(const QRect& r, bool translate = true) override;
+    void invalidate(const QRegion& r, bool translate = true) override;
 
-    void paintEvent(QPaintEvent *event) Q_DECL_OVERRIDE;
+    void paintEvent(QPaintEvent *event) override;
 
 private Q_SLOTS:
     void processAnimations();
@@ -599,15 +599,15 @@ public:
     /** Set the delay of the animation, in milliseconds */
     void setAnimationDelay(int d);
 
-    /** Return the number of millisecons from the creation of the canvas
+    /** Return the number of milliseconds from the creation of the canvas
         (see also KGameCanvasItem::advance)*/
     int mSecs();
 
     /** returns 'this' */
-    KGameCanvasWidget* topLevelCanvas() Q_DECL_OVERRIDE;
+    KGameCanvasWidget* topLevelCanvas() override;
 
     /** @return 0 */
-    QPoint canvasPosition() const Q_DECL_OVERRIDE;
+    QPoint canvasPosition() const override;
 };
 
 /**
@@ -639,10 +639,10 @@ class KDEGAMESPRIVATE_EXPORT KGameCanvasAdapter : public KGameCanvasAbstract
     bool m_child_rect_valid;
     QRect m_invalidated_rect;
 
-    void ensureAnimating() Q_DECL_OVERRIDE { }
-    void ensurePendingUpdate() Q_DECL_OVERRIDE;
-    void invalidate(const QRect& r, bool translate = true) Q_DECL_OVERRIDE;
-    void invalidate(const QRegion& r, bool translate = true) Q_DECL_OVERRIDE;
+    void ensureAnimating() override { }
+    void ensurePendingUpdate() override;
+    void invalidate(const QRect& r, bool translate = true) override;
+    void invalidate(const QRegion& r, bool translate = true) override;
 
     QRect childRect();
 public:
@@ -653,7 +653,7 @@ public:
       * An adapter is not associated to any canvas, so this function
       * simply returns 0.
       */
-    class KGameCanvasWidget* topLevelCanvas() Q_DECL_OVERRIDE { return 0; }
+    class KGameCanvasWidget* topLevelCanvas() override { return 0; }
 
     /**
       * The absolute position of the rendered content is not well
@@ -664,7 +664,7 @@ public:
       *
       * @return The point (0, 0).
       */
-    QPoint canvasPosition() const Q_DECL_OVERRIDE { return QPoint(0, 0); }
+    QPoint canvasPosition() const override { return QPoint(0, 0); }
 
     /**
       * Draw the items of the adapter using the specified painter.
