@@ -69,7 +69,7 @@ KGameThemeSelector::~KGameThemeSelector()
 void KGameThemeSelector::KGameThemeSelectorPrivate::setupData(KConfigSkeleton * aconfig, KGameThemeSelector::NewStuffState knsflags)
 {
     ui.setupUi(q);
-    ui.getNewButton->setIcon(QIcon::fromTheme( QLatin1String( "get-hot-new-stuff" )));
+    ui.getNewButton->setIcon(QIcon::fromTheme( QStringLiteral( "get-hot-new-stuff" )));
 
     //The lineEdit widget holds our theme path for automatic connection via KConfigXT.
     //But the user should not manipulate it directly, so we hide it.
@@ -82,7 +82,7 @@ void KGameThemeSelector::KGameThemeSelectorPrivate::setupData(KConfigSkeleton *
     }
 
     //Get the last used theme path from the KConfigSkeleton
-    KConfigSkeletonItem * configItem = aconfig->findItem(QLatin1String( "Theme" ));
+    KConfigSkeletonItem * configItem = aconfig->findItem(QStringLiteral( "Theme" ));
     QString lastUsedTheme = configItem->property().toString();
 
     //Now get our themes into the list widget
@@ -105,7 +105,7 @@ void KGameThemeSelector::KGameThemeSelectorPrivate::findThemes(const QString &in
     QStringList themesAvailable;
 
     const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QCoreApplication::applicationName() + QLatin1Char( '/' ) + lookupDirectory, QStandardPaths::LocateDirectory);	//Added subdirectory for finding gamethemeselector resources
-    Q_FOREACH(const QString& dir, dirs) {
+    for (const QString& dir : dirs) {
 	    QDirIterator it(dir, QStringList() << QStringLiteral("*.desktop"), QDir::NoFilter, QDirIterator::Subdirectories);
 	    while (it.hasNext()) {
                     QFileInfo fileInfo(it.next());
@@ -115,13 +115,13 @@ void KGameThemeSelector::KGameThemeSelectorPrivate::findThemes(const QString &in
     }
 
     bool initialFound = false;
-    foreach (const QString &file, themesAvailable)
+    for (const QString &file : qAsConst(themesAvailable))
     {
       const QString themePath = lookupDirectory + QLatin1Char( '/' ) + file;
       KGameTheme* atheme = new KGameTheme(groupName);
 
       if (atheme->load(themePath)) {
-        QString themeName = atheme->themeProperty(QLatin1String( "Name" ));
+        QString themeName = atheme->themeProperty(QStringLiteral( "Name" ));
         //Add underscores to avoid duplicate names.
         while (themeMap.contains(themeName))
           themeName += QLatin1Char( '_' );
@@ -142,12 +142,12 @@ void KGameThemeSelector::KGameThemeSelectorPrivate::findThemes(const QString &in
     if (!initialFound)
     {
       // TODO change this if we ever change KGameTheme::loadDefault
-      QString defaultPath = QLatin1String( "themes/default.desktop" );
+      QString defaultPath = QStringLiteral( "themes/default.desktop" );
       foreach(KGameTheme* theme, themeMap)
       {
         if (theme->path().endsWith(defaultPath))
         {
-          const QList<QListWidgetItem *> itemList = ui.themeList->findItems(theme->themeProperty(QLatin1String( "Name" )), Qt::MatchExactly);
+          const QList<QListWidgetItem *> itemList = ui.themeList->findItems(theme->themeProperty(QStringLiteral( "Name" )), Qt::MatchExactly);
           // never can be != 1 but better safe than sorry
           if (itemList.count() == 1)
           {
@@ -172,9 +172,9 @@ void KGameThemeSelector::KGameThemeSelectorPrivate::_k_updatePreview()
     }
     ui.kcfg_Theme->setText(seltheme->fileName());
 
-    QString authstr(QLatin1String( "Author" ));
-    QString contactstr(QLatin1String( "AuthorEmail" ));
-    QString descstr(QLatin1String( "Description" ));
+    QString authstr(QStringLiteral( "Author" ));
+    QString contactstr(QStringLiteral( "AuthorEmail" ));
+    QString descstr(QStringLiteral( "Description" ));
     QString emailstr;
     if (!seltheme->themeProperty(contactstr).isEmpty() ) {
         emailstr = QString::fromLatin1( "<a href=\"mailto:%1\">%1</a>").arg(seltheme->themeProperty(contactstr));
